function [V,spk]=simpleiandf(E_L,V_res,V_th,tau_m,R_m,I_e,dt,n)

% ultra-simple implementation of integrate-and-fire model
% inputs:
% E_L    = leak potential           [e.g. -65 mV]
% V_res  = reset potential          [e.g. E_L]
% V_th   = threshold potential      [e.g. -50 mV]
% tau_m  = membrane time constant   [e.g. 10 ms]
% R_m    = membrane resistance      [e.g. 10 MOhm]
% I_e    = external input           [e.g. white noise]
% dt     = time step                [e.g. 0.1 ms]
% n      = number of time points    [e.g. 1000]
%
% returns
% V      = intracellular voltage    [n x 1]
% spk    = 0 or 1 indicating spikes [n x 1]

V(1)=V_res;      % initial voltage
spk=zeros(n,1);
for t=2:n
    V(t)=V(t-1)+(dt/tau_m) * (E_L - V(t-1) + R_m * I_e(t));     % Key line computing the change in voltage at time t
    if (V(t)>V_th)                                              % Emit a spike if V is above threshold
        V(t)=V_res;                                             % And reset the voltage
        spk(t)=1;
    end
end

